==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ANullBaseType.h <==
// public final class soot.jimple.parser.node.ANullBaseType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d6a5e2ea586ac084 soot_jimple_parser_node_ANullBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_ANullBaseType_H_
#define _JC_soot_jimple_parser_node_ANullBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TNullType$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ANullBaseType$sub_refs	_jc_soot_jimple_parser_node_ANullBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ANullBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_ANullBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANullBaseType$refs	_jc_soot_jimple_parser_node_ANullBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_ANullBaseType$nonrefs	_jc_soot_jimple_parser_node_ANullBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANullBaseType$object	_jc_soot_jimple_parser_node_ANullBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_ANullBaseType$vmethods	_jc_soot_jimple_parser_node_ANullBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ANullBaseType$vtable	_jc_soot_jimple_parser_node_ANullBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_ANullBaseType$vtype	_jc_soot_jimple_parser_node_ANullBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ANullBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *);
extern void _jc_soot_jimple_parser_node_ANullBaseType$method$_init$de7b4356e0506287(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *, struct _jc_soot_jimple_parser_node_TNullType$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ANullBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ANullBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *);
extern struct _jc_soot_jimple_parser_node_TNullType$object *_jc_soot_jimple_parser_node_ANullBaseType$method$getNullType$b7414e20688fb682(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *);
extern void _jc_soot_jimple_parser_node_ANullBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ANullBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ANullBaseType$method$setNullType$3f34deec3b3ca0db(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *, struct _jc_soot_jimple_parser_node_TNullType$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ANullBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseType$method_info$getNullType$b7414e20688fb682;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseType$method_info$setNullType$3f34deec3b3ca0db;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ANullBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *);
	struct _jc_soot_jimple_parser_node_TNullType$object	*(*getNullType$b7414e20688fb682)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setNullType$3f34deec3b3ca0db)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *, struct _jc_soot_jimple_parser_node_TNullType$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ANullBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_ANullBaseType$vmethods	soot_jimple_parser_node_ANullBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_ANullBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ANullBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANullBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_TNullType$object	*__5fnullType__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANullBaseType$refs {
    _jc_soot_jimple_parser_node_ANullBaseType$sub_refs	soot_jimple_parser_node_ANullBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANullBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANullBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_ANullBaseType$sub_nonrefs	soot_jimple_parser_node_ANullBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ANullBaseType$object {
	_jc_soot_jimple_parser_node_ANullBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ANullBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_ANullBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ANullBaseType$vtype _jc_soot_jimple_parser_node_ANullBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ANullBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ANullBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_ANullBaseType_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ANullBaseType.h <==
// public final class soot.jimple.parser.node.ANullBaseType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d6a5e2ea586ac084 soot_jimple_parser_node_ANullBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_ANullBaseType_H_
#define _JC_soot_jimple_parser_node_ANullBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TNullType$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ANullBaseType$sub_refs	_jc_soot_jimple_parser_node_ANullBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ANullBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_ANullBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANullBaseType$refs	_jc_soot_jimple_parser_node_ANullBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_ANullBaseType$nonrefs	_jc_soot_jimple_parser_node_ANullBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANullBaseType$object	_jc_soot_jimple_parser_node_ANullBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_ANullBaseType$vmethods	_jc_soot_jimple_parser_node_ANullBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ANullBaseType$vtable	_jc_soot_jimple_parser_node_ANullBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_ANullBaseType$vtype	_jc_soot_jimple_parser_node_ANullBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ANullBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANullBaseType$method$_init$de7b4356e0506287(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *, struct _jc_soot_jimple_parser_node_TNullType$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ANullBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ANullBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TNullType$object *_jc_soot_jimple_parser_node_ANullBaseType$method$getNullType$b7414e20688fb682(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANullBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANullBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANullBaseType$method$setNullType$3f34deec3b3ca0db(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *, struct _jc_soot_jimple_parser_node_TNullType$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ANullBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseType$method_info$getNullType$b7414e20688fb682;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseType$method_info$setNullType$3f34deec3b3ca0db;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ANullBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TNullType$object	*(*getNullType$b7414e20688fb682)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setNullType$3f34deec3b3ca0db)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *, struct _jc_soot_jimple_parser_node_TNullType$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ANullBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_ANullBaseType$vmethods	soot_jimple_parser_node_ANullBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_ANullBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ANullBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANullBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_TNullType$object	*__5fnullType__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANullBaseType$refs {
    _jc_soot_jimple_parser_node_ANullBaseType$sub_refs	soot_jimple_parser_node_ANullBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANullBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANullBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_ANullBaseType$sub_nonrefs	soot_jimple_parser_node_ANullBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ANullBaseType$object {
	_jc_soot_jimple_parser_node_ANullBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ANullBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_ANullBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ANullBaseType$vtype _jc_soot_jimple_parser_node_ANullBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ANullBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ANullBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_ANullBaseType_H_ */
